Module blaxel.core.client.models.resource
=========================================

Classes
-------

`Resource(infrastructure_generation: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, name: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, type_: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, workspace: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, workspace_id: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>)`
:   Resource
    
    Attributes:
        infrastructure_generation (Union[Unset, str]): Region of the resource
        name (Union[Unset, str]): Name of the resource
        type_ (Union[Unset, str]): Type of the resource
        workspace (Union[Unset, str]): Workspace of the resource
        workspace_id (Union[Unset, str]): Workspace ID of the resource
    
    Method generated by attrs for class Resource.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `infrastructure_generation: blaxel.core.client.types.Unset | str`
    :

    `name: blaxel.core.client.types.Unset | str`
    :

    `type_: blaxel.core.client.types.Unset | str`
    :

    `workspace: blaxel.core.client.types.Unset | str`
    :

    `workspace_id: blaxel.core.client.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :